IndexOverlay

Struct IndexOverlay 

pub struct IndexOverlay(/* private fields */);
Overlay for tracking uncommited transaction changes to indexes on a table.

1 Table has 1 IndexOverlay, which has n BTreeMaps for each index

Implementations

Source

impl IndexOverlay

pub fn insert( &mut self, indexed_columns: &[&'static str], indexed_values: Vec<Value>, pk: Value, )

Inserts a record into the index overlay for the specified indexed columns, indexed values, and primary key.

The primary key is added to the set of primary keys associated with the indexed values in the added map. If the primary key was previously in the removed set for these values, it is removed from there.

pub fn delete( &mut self, indexed_columns: &[&'static str], indexed_values: Vec<Value>, pk: Value, )

Removes a record from the index overlay for the specified indexed columns, indexed values, and primary key.

The primary key is added to the set of primary keys associated with the indexed values in the removed map. If the primary key was previously in the added set for these values, it is removed from there.

pub fn added_pks( &self, indexed_columns: &[&'static str], indexed_values: &[Value], ) -> HashSet<Value>

Returns the set of primary keys added for the given index columns and indexed values.

Returns an empty set if no entries exist.

pub fn removed_pks( &self, indexed_columns: &[&'static str], indexed_values: &[Value], ) -> HashSet<Value>

Returns the set of primary keys removed for the given index columns and indexed values.

Returns an empty set if no entries exist.

pub fn added_pks_in_range( &self, indexed_columns: &[&'static str], start: Option<&[Value]>, end: Option<&[Value]>, ) -> HashSet<Value>

Returns the set of primary keys added within the given inclusive key range.

pub fn removed_pks_in_range( &self, indexed_columns: &[&'static str], start: Option<&[Value]>, end: Option<&[Value]>, ) -> HashSet<Value>

Returns the set of primary keys removed within the given inclusive key range.

pub fn update( &mut self, indexed_columns: &[&'static str], old_indexed_values: Vec<Value>, new_indexed_values: Vec<Value>, pk: Value, )

Updates a record in the index overlay by removing the old indexed values and inserting the new ones.

This is equivalent to calling delete with the old values followed by insert with the new values.